##  Overview
The transformation explorer provides a comprehensive overview of all transformation items within your workspace. It enables you to edit, execute, sort, filter, and delete transformations efficiently, helping you manage and track your transformation activities in one place.
![Transformations Explorer in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocdfd81c3ae9c479d9ba6d423fce889b3_LowRes.png)
Transformations Explorer in SAP LeanIX
